# Data Funcs
Functions for Data Processing

## Functions

.mean(data) - Returns the mean of a list

.grt(data, value) - Returns the mean of a list for values greater than specified

.grtEqual(data, value) - Returns the mean of a list for values greater than or equal to specified

.less(data, value) - Returns the mean of a list for values less than specified

.lessEqual(data, value) - Returns the mean of a list for values less than or equal to specified

.notEqual(data, value) - Returns the mean of a list for values not equal to specified

.outlier(data, low, high) - Removes the outliers from a list

.imputate(data, low, high) - Replaces outliers in a list with the mean of the filtered list.

.median(data) - Returns the median of a list

.mode(data) - Returns the mode of a list

.freq(data, value) - Returns the Amount of times that a value occurs in the list data

.Range(data) - Returns the range of the list

.replace(data, old, new) - Replaces every old value in the list with the new value
 
.gen(length, low, high, type) - Generates a list of random values of the type specified that is length long - Ignore the low and high values if you are not generating a list of integers

.all(data) - Returns everything the script knows about a list

.Help() - Prints a list of the above functions and their explanations

### Created by Liam Leonard & Fraser Woodward
